@@ -1,12 +1,16 @@
 package Text::SimpleTable::AutoWidth;
 
-use Moose;
+use Moo;
 
-our $VERSION = '0.04';
+our $VERSION = '0.06';
 
 =head1 NAME
 
-Text::SimpleTable::AutoWidth - Simple Eyecandy ASCII Tables with auto-width selection
+Text::SimpleTable::AutoWidth - Simple eyecandy ASCII tables with auto-width selection
+
+=head1 VERSION
+
+Version is 0.05
 
 =head1 SYNOPSIS
 
@@ -44,7 +48,7 @@ as seen in L<Catalyst>.
 
 =head2 new(@attrs)
 
-Inherited constructor from Moose.
+Inherited constructor from Moo.
 You can set following attributes:
 
 =head3 fixed_width
@@ -82,11 +86,11 @@ You can use next method to add individual rows into table.
 
 =cut
 
-has 'fixed_width' => ( is => 'rw', isa => 'Int', default => 0 );
-has 'max_width'   => ( is => 'rw', isa => 'Int', default => 0 );
+has 'fixed_width' => ( is => 'rw', default => 0 );  # isa => 'Int'
+has 'max_width'   => ( is => 'rw', default => 0 );  # isa => 'Int'
 
-has 'captions' => ( is => 'rw', isa => 'ArrayRef[Str]' );
-has 'rows'     => ( is => 'rw', isa => 'ArrayRef[ArrayRef[Str]]' );
+has 'captions' => ( is => 'rw' );                   # isa => 'ArrayRef[Str]'
+has 'rows'     => ( is => 'rw' );                   # isa => 'ArrayRef[ArrayRef[Str]]'
 
 our $WIDTH_LIMIT = 200;    # default maximum width
 
@@ -228,25 +232,13 @@ sub draw {
 
 __PACKAGE__->meta->make_immutable();
 
+=head1 GIT REPOSITORY
+
+git clone git://github.com/cub-uanic/Text-SimpleTable-AutoWidth.git
+
 =head1 SEE ALSO
 
-L<Text::SimpleTable>, L<Moose>, L<Catalyst>
-
-=head1 SUPPORT
-
-=over 4
-
-=item * Report bugs or feature requests
-
-L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Text-SimpleTable-AutoWidth>
-
-L<http://www.assembla.com/spaces/Text-SimpleTable-AutoWidth/tickets>
-
-=item * Git repository
-
-git clone git://git.assembla.com/Text-SimpleTable-AutoWidth.git
-
-=back
+L<Text::SimpleTable>, L<Moo>, L<Catalyst>
 
 =head1 AUTHOR
 
